#
# spec file for package icu4j
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2000-2007, JPackage Project
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           icu4j
Version:        60.2
Release:        lp151.2.43
Summary:        International Components for Unicode for Java
License:        MIT AND EPL-1.0
Group:          Development/Libraries/Java
Url:            http://site.icu-project.org/
#CAUTION
#to create a tarball use following procedure
#svn co http://source.icu-project.org/repos/icu/tags/release-60-2/icu4j icu4j-<version>
#tar caf icu4j-<version>.tar.xz icu4j-<version>/
Source0:        %{name}-%{version}.tar.xz
Patch0:         icu4j-jdk10plus.patch
BuildRequires:  ant
BuildRequires:  fdupes
BuildRequires:  java-devel
BuildRequires:  javapackages-local
BuildRequires:  javapackages-tools
BuildRequires:  unzip
BuildRequires:  zip
BuildArch:      noarch

%description
The International Components for Unicode (ICU) library provides robust and
full-featured Unicode services on a wide variety of platforms. ICU supports
the most current version of the Unicode standard, and provides support for
supplementary characters (needed for GB 18030 repertoire support).

Java provides a very strong foundation for global programs, and IBM and the
ICU team played a key role in providing globalization technology into Sun's
Java. But because of its long release schedule, Java cannot always keep
up-to-date with evolving standards. The ICU team continues to extend Java's
Unicode and internationalization support, focusing on improving
performance, keeping current with the Unicode standard, and providing
richer APIs, while remaining as compatible as possible with the original
Java text and internationalization API design.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML

%description javadoc
Javadoc documentation for %{name}.

%prep
%setup -q
%patch0 -p1

sed -i 's/\r//' APIChangeReport.html
sed -i 's/\r//' readme.html

sed --in-place "s/ .*bootclasspath=.*//g" build.xml
sed --in-place "s/<date datetime=.*when=\"after\"\/>//" build.xml
sed --in-place "/javac1.3/d" build.xml
sed --in-place "s:%{_prefix}/lib:%{_libdir}:g" build.xml
rm -f tools/build/src/com/ibm/icu/dev/tool/docs/ICUTaglet*.java

%build
ant \
    -Dicu4j.javac.source=1.6 -Dicu4j.javac.target=1.6 \
    -Dj2se.apidoc=%{_javadocdir}/java \
    jar docs

%install
# jars
mkdir -p %{buildroot}%{_javadir}
cp -ap %{name}.jar %{buildroot}%{_javadir}/%{name}.jar

# javadoc
mkdir -p %{buildroot}%{_javadocdir}/%{name}
cp -pr doc/* %{buildroot}%{_javadocdir}/%{name}
%fdupes -s %{buildroot}%{_javadocdir}/%{name}

# maven stuff
install -d -m 755 %{buildroot}%{_mavenpomdir}
cp maven/icu4j/pom.xml %{buildroot}%{_mavenpomdir}/JPP-%{name}.pom
%add_maven_depmap JPP-%{name}.pom %{name}.jar

%files
%doc readme.html APIChangeReport.html
%{_javadir}/%{name}*.jar
%if %{defined _maven_repository}
%{_mavendepmapfragdir}/%{name}
%else
%{_datadir}/maven-metadata/%{name}.xml*
%endif
%{_mavenpomdir}/*.pom

%files javadoc
%{_javadocdir}/%{name}

%changelog
* Fri Dec 22 2017 fstrba@suse.com
- Version update to 60.2
  * jdk9 upstream fixes
- Obsoleted patches:
  * icu4j-jdk9.patch
  - Obsoleted by upstream fixes
  * icu4j-taglet.patch
  - Obsoleted by removal of the old style taglet removal
- Added patch:
  * icu4j-jdk10plus.patch
  - Fix build with jdk10 and possibly later jdks
- Don't build the ICUTaglet, since it depends on removed APIs
* Fri Sep 29 2017 fstrba@suse.com
- Don't condition the maven defines on release version, but on
  _maven_repository being defined
* Mon Sep 18 2017 fstrba@suse.com
- Added patches:
  * icu4j-taglet.patch
    + implement com.sun.tools.doclets.Taglet interface instead of
    the deprecated
    com.sun.tools.doclets.internal.toolkit.taglets.Taglet
    + Fixes java.lang.ClassCastException with jdk9
  * icu4j-jdk9.patch
    + Extend the jdk9 test, so that it accepts versions that start
    with 9
    + Make source, target and encoding consistent all over the
    build
- Specify source and target level 1.6 in order to allow building
  with jdk9
* Fri May 19 2017 tchvatal@suse.com
- Version update to 58.1:
  * Changes to keep in line with regular icu release
- Obsoleted patch:
  * java8-compatibility.patch
* Mon Mar 20 2017 sknorr@suse.com
- Needed as a dependency for FOP 2.1 (fate#322405)
- Switch between maven-metadata/maven-fragments as appropriate
  for SLE/openSUSE (fate#322405)
* Tue Jul 28 2015 tchvatal@suse.com
- Version bump to 55.1:
  * various bugfixes to match up regular icu-c
- Add patch to build with jdk8:
  * java8-compatibility.patch
* Wed Mar 18 2015 tchvatal@suse.com
- Fix build with new javapackages-tools
* Tue Jan 20 2015 p.drouand@gmail.com
- Update to version 54.1.1
  * CLDR 26
  * Unicode 7.0
  * many more units
  * Unihan in root collation
  * new RBNF PluralFormat syntax
  * dictionary-based break iterator for Burmese
  * tech preview of FilteredBreakIterator using ULI break data
* Fri Jul 18 2014 tchvatal@suse.com
- Version bump to 52.1:
  * Match the 52.1 icu release.
* Fri Jun 27 2014 tchvatal@suse.com
- No need to depend on java-javadoc solves build for SLE11.
- Tidy a bit with spec-cleaner
* Mon Sep  9 2013 tchvatal@suse.com
- Move from jpackage-utils to javapackage-tools
* Sat Feb  2 2013 p.drouand@gmail.com
- Update to version 50.1:
  * Common Changes
  - Unicode 6.2: Turkish Lira Sign, improved word & line segmentation
    (BreakIterator) for symbols
  - CLDR 22.1: Data coverage & quality improved across all major languages;
    new short width type for weekday names; new zhuyin (Bopomofo) collation
    for Chinese; improved data for CompactDecimalFormat & RBNF
  - Time zone data: 2012h
  - Ordinal-number support in MessageFormat & PluralRules (#9132)
  - Deprecate setLocale(locale) in PluralFormat (#9249)
  - Dictionary-based break iterators (word segmentation):
  * Support Chinese & Japanese, use more compact dictionary format,
    port all but Khmer support to Java (#9353)
  * Update Khmer dictionary (#9311)
  - Change Java util.ListFormat to text.ListFormatter and other updates,
    use CLDR data (#9369, #9420), port to C++ (#7168)
  - Add updated IBM-eucJP and IBM-5233 converter (#9262, #9259)
  * ICU4C Specific Changes
  - Improve number formatting performance (#9258)
  - C++ GenderInfo: Effective combined gender of a list of people's genders
    (#9598) (ported from Java)
  - Thread safety support cannot be removed (see the Readme)
  - Default compilers: Clang is now used if available (see the Readme)
  - C++ Collator API cleanup (#9346, #9406, #9460), subclassing-API-breaking
    changes (see the Readme)
  - Add option to genrb tool for writing java resource bundle files (#9271)
  - Time zone format APIs (#9338)
  * ICU4J Specific Changes
  - class DictionaryBasedBreakIterator was removed as part of the improvements
    for dictionary-based break iteration; see the note in the readme
  - Dangi (Korean Lunisolar) calendar (#9255)
- Remove external manifest file: icu4j has moved to the IBM api
- Add with_ecplise macros; working on it
* Wed Nov 28 2012 p.drouand@gmail.com
- Update to 4.8.1.1 :
  * CLDR 2.0: The CLDR 2.0 release contains numerous improvements and
    bug fixes approved by the CLDR committee, including much additional data for many languages.
  * Explicit parent locale support in data imported from CLDR (#8031)
  * MessageFormat and related classes (choice/plural/select) have been reimplemented,
    with several improvements and some incompatible changes. See the detail section below.
  * Extended PluralFormat pattern syntax supports explicit-value forms and offsets. (#7858)
  * Utility APIs in PluralRules (get some/all/unique keyword values)
  * Time zone API to return a list of available canonical system time zone IDs (#8278)
  * Time zone API to return a region (#8279)
  * Collation: Full implementation & public API for script reordering
  * Dictionary-type trie (#8167)
  * GB18030-2005 update (#8274)
  * Alphabetic Index support ported from ICU4J (#7538)
  * X11 Compound Text encoding support ported from ICU4J (#7959)
  * Appendable interface (#8314)
  * Technology Preview: APIs for region information. The new class
  com.ibm.icu.util.Region provides mapping across different region/territory codes and
  containment relationship. (#8347)
  * JDK Locale conversion to support JDK 7 new Locale fields (#8078)
  * Technology Preview: TimeZoneFormat and TimeZoneNames. New classes designed for
    supporting CLDR time zone display name algorithm and data through public APIs. (#8342)
  * Known Issues
    [#8535] & #8537 (C only) Prebuilt binaries are usable on MinGW but the MinGW build is broken
    [#8571] (C only) U_HIDE_DRAFT_API does not operate on the correct set of APIs; might also affect
    U_HIDE_DEPRECATED_API, U_HIDE_INTERNAL_API and U_HIDE_SYSTEM_API
- Deleted files :
  * icu4j-4.4.2.pom : Now icu4j is enterly based on IBM Api
* Tue Jun 12 2012 mvyskocil@suse.cz
- update to 4.4.2.2 (sync with Fedora)
  * CLDR 1.8
  * Unicode 5.2
  * compact resource bundle
  * Java 5 syntax
* Tue Jun  2 2009 mvyskocil@suse.cz
- Initial SUSE packaging of icu4j (from jpackage5.0)
